@@ -49,6 +49,26 @@ class KnockPY(object):
         except Exception as e:
             print("[Knockpy bufferover_run ERROR]", e, flush=True)
             return []
+    
+    async def virustotal_subdomain(self):
+        try:
+            if not self.virustotalapi:
+                return []
+                
+            url = "https://www.virustotal.com/api/v3/domains/{domain}/subdomains".format(domain=self.domain)
+            headers= {"x-apikey":self.virustotalapi}
+            
+            subdomains = []
+            
+            async with httpx.AsyncClient() as client:
+                req = await client.get(url, headers=headers, timeout=self.timeout)
+                data = req.json().get("data")
+                for d in data:
+                    subdomains.app(d.get("id"))
+            return subdomains 
+        except Exception as e:
+            print("[Knockpy virustotal_subdomain ERROR, Fallback failed]", e, flush=True)
+            return []
             
     async def virustotal(self):
         """@return List"""
@@ -68,8 +88,8 @@ class KnockPY(object):
             return subdomains
             
         except Exception as e:
-            print("[Knockpy virustotal ERROR]", e, flush=True)
-            return []
+            print("[Knockpy virustotal ERROR, Using fallback]", e, flush=True)
+            return await self.virustotal_subdomain()
     
     async def hackertarget(self):
         """@return List"""
@@ -183,8 +203,11 @@ class KnockPY(object):
         subdomains = []
 
         print("Searching binary_edge")
-        subdomains += await self.binary_edge()
+        binary_subdomains += await self.binary_edge()
         
+        if binary_subdomains:
+            subdomains += binary_subdomains
+            
         print("Searching virustotal")
         subdomains += await self.virustotal()
         
